@@ -16,7 +16,9 @@ from selenium.webdriver.chrome.options import Options as ChromeOptions
 from .logger import get_logger
 
 
-def get_browser_options(browser: str, keep_head: bool = False, use_proxy: Optional[str] = None) -> Any:
+def get_browser_options(
+    browser: str, keep_head: bool = False, use_proxy: Optional[str] = None
+) -> Any:
     try:
         options = {"Firefox": FirefoxOptions(), "Chrome": ChromeOptions()}[browser]
     except KeyError:
@@ -53,9 +55,17 @@ def pick_best_actual_image(actual_images: List[WebElement]) -> WebElement:
     else:
         scores = defaultdict(int)
         for i, actual_image in enumerate(actual_images):
-            scores[i] += 1
-            if "encrypted-tbn0.gstatic.com" in actual_image.get_attribute("src"):
-                scores[i] -= 1
+            try:
+                scores[i] += 1
+                if "encrypted-tbn0.gstatic.com" in actual_image.get_attribute("src"):
+                    scores[i] -= 1
+            except selenium.common.exceptions.StaleElementReferenceException as exc:
+                # this error is often accompanied by: Message: stale element reference: element is not attached to the page document
+                # could be some race condition, or maybe the page is changing between the actual_images getting populated and this method getting called
+                # either way - we will continue here and raise an error later if there are no images to choose from
+                continue
+        if len(scores) == 0:
+            raise NoImagesInWebElementError()
         top_scorers = list()
         for i, score in enumerate(scores):
             if score == max(scores.values()):
@@ -151,7 +161,9 @@ def fetch_google_image_urls(
                     if skipped_empty_elements >= 10:
                         page_source_file = Path(tempfile.NamedTemporaryFile().name)
                         page_source_file.write_text(driver.page_source)
-                        raise NoImagesInWebElementError(f"wrote page source to: {page_source_file}") from exc
+                        raise NoImagesInWebElementError(
+                            f"wrote page source to: {page_source_file}"
+                        ) from exc
                     continue
             image_link = dict()
             if actual_image.get_attribute(
